# 🔗 More

Here are some additional details about the library

````{grid}
:gutter: 2

```{grid-item-card} 🥹 Contributing
:link: contributing
:link-type: ref

We welcome contributions from the community to help improve our product and make it even more robust. Checkout the step-by-step guide on how you can contribute to Ragrank
```

```{grid-item-card} 📁 Security
:link: security
:link-type: ref

We take security seriously and value the contributions of security researchers. If you discover a security vulnerability within Ragrank, please report it to us promptly.
```

````

```{toctree}
:hidden:

about_us
contributing
security
```